/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.shapetype;

import com.vividsolutions.jts.geom.Envelope;
import com.vividsolutions.jts.geom.Geometry;
import com.vividsolutions.jts.geom.GeometryCollection;
import com.vividsolutions.jts.geom.Point;
import java.util.List;
import nl.cloudfarming.client.geometry.model.Shape;
import nl.cloudfarming.client.geoviewer.Geographical;
import org.geotools.coverage.grid.GridCoverage2D;

/**
 * A class which can be fed a list of shapes From this list of shapes is
 * constructs a geometry collection This collection can be asked for it's
 * centroid
 *
 * @author Merijn Zengers
 */
public class ShapeCollection implements Geographical<GridCoverage2D> {

    private List<Shape> shapes;

    public ShapeCollection(List<Shape> shapes) {
        this.shapes = shapes;
    }

    @Override
    public Point getCentroid() {
        Geometry[] geometries = new Geometry[shapes.size()];
        int counter = 0;
        for (Shape shape : shapes) {
            geometries[counter] = shape.getGeometry();
            counter++;
        }
        GeometryCollection collection = new GeometryCollection(geometries, geometries[0].getFactory());
        return collection.getCentroid();
    }

    @Override
    public Geometry getBoundingBox() {
        Geometry[] geometries = new Geometry[shapes.size()];
        int counter = 0;
        for (Shape shape : shapes) {
            geometries[counter] = shape.getGeometry();
            counter++;
        }
        GeometryCollection collection = new GeometryCollection(geometries, geometries[0].getFactory());
        return collection.getEnvelope();
    }

    @Override
    public GridCoverage2D getRenderObject(Envelope envelope) {
        return null;
    }

    @Override
    public String getTooltipText() {
        return "";
    }

    @Override
    public long getId() {
        return 1l;
    }

    @Override
    public String getIconPath() {
        return null;
    }

    @Override
    public String getIconLabel() {
        return null;
    }
}
