/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.shapetype.preview;

import java.awt.Graphics;
import javax.swing.JLabel;
import javax.swing.JPanel;
import net.miginfocom.swing.MigLayout;
import nl.cloudfarming.client.geometry.model.Shape.ImportType;

/**
 * Displays a legend for the map.
 * 
 * @author Gerben Feenstra
 */

public class MapLegendPanel extends JPanel{
    
    private PreviewPanelPalette palette;
    private final JLabel skipLabel = new JLabel(ImportType.SKIP.getDisplayName());
    private final JLabel importLabel = new JLabel(ImportType.IMPORT.getDisplayName());
    private static final int COLORCUBE_WIDTH = 25;
    private static final int COLORCUBE_HEIGHT = 15;
    private static final int LABEL_CUBE_DISTANCE = 100;
    
    
    public MapLegendPanel(PreviewPanelPalette palette){
        this.palette = palette;
        this.setLayout(new MigLayout("wrap 1"));
        this.add(skipLabel);
        this.add(importLabel);
    }
    
    @Override
    public void paint (Graphics g) {
        super.paint(g);
        
        // SKIP
        g.setColor(palette.getColorForValue(ImportType.SKIP));
        int xSkipLoc = skipLabel.getLocation().x + LABEL_CUBE_DISTANCE;
        int ySkipLoc = skipLabel.getLocation().y;
        g.fillRect(xSkipLoc, ySkipLoc, COLORCUBE_WIDTH, COLORCUBE_HEIGHT);
        
        // IMPORT
        g.setColor(palette.getColorForValue(ImportType.IMPORT));
        int xImportLoc = importLabel.getLocation().x + LABEL_CUBE_DISTANCE;
        int yImportLoc = importLabel.getLocation().y;
        g.fillRect(xImportLoc, yImportLoc, COLORCUBE_WIDTH, COLORCUBE_HEIGHT);
    }
    
}
