/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.shapetype.preview;

import java.awt.Color;
import java.awt.Dimension;
import javax.swing.BorderFactory;
import javax.swing.JPanel;
import javax.swing.border.Border;
import javax.swing.border.EtchedBorder;
import net.miginfocom.swing.MigLayout;
import org.openide.util.NbBundle;

/**
 *
 * @author Gerben Feenstra
 */
@NbBundle.Messages({
    "Import.geometrical.wizard.panel.geo_import_support.panel.legend.label=Legend",
    "Import.geometrical.wizard.panel.geo_import_support.panel.shape_properties.label=Properties",
    "Import.geometrical.wizard.panel.geo_import_support.panel.mark_as.label=Mark all shapes as",
    "Shape_property_mapping_panel=Property Mapping:"
})
public class ShapePreviewPanel extends JPanel {

    private static final int LEFT_PANEL_WIDTH = 10000;
    private static final int LEFT_PANEL_HEIGHT = 10000;
    private static final int RIGHT_PANEL_WIDTH = 220;
    private static final int MAP_LEGEND_PANEL_HEIGHT = 70; 
    private static final int PROPERTIES_PANEL_HEIGHT = 120; 
    private static final int MAPPING_PANEL_HEIGHT = 85; 
    
    // Panels
    private ShapesPanel leftPanel;
    private ShapePropertiesPanel shapePropertiesPanel;
    private ShapePropertyMappingPanel shapePropertyMappingPanel;
    private MapLegendPanel mapLegendPanel;
    private MarkAsPanel markAsPanel;
    private final JPanel rightPanel = new JPanel(new MigLayout("wrap 1, insets 0 0 0 0"));

    /**
     * Use the builder to construct
     */
    private ShapePreviewPanel() {
        this.setLayout(new MigLayout("wrap 2", "left", "top"));
        rightPanel.setBackground(Color.white);
    }

    public String getSelectedNameProperty() {
        return shapePropertyMappingPanel.getSelectedNameProperty();
    }

    public ShapesPanel getLeftPanel() {
        return leftPanel;
    }

    private void setLeftPanel(ShapesPanel leftPanel) {
        this.leftPanel = leftPanel;
        leftPanel.setPreferredSize(new Dimension(LEFT_PANEL_WIDTH, LEFT_PANEL_HEIGHT));
        leftPanel.setBorder(new EtchedBorder());
        this.add(leftPanel);
    }

    public MapLegendPanel getMapLegendPanel() {
        return mapLegendPanel;
    }

    private void setMapLegendPanel(MapLegendPanel mapLegendPanel) {
        this.mapLegendPanel = mapLegendPanel;
        mapLegendPanel.setMinimumSize(new Dimension(RIGHT_PANEL_WIDTH, MAP_LEGEND_PANEL_HEIGHT));
        mapLegendPanel.setPreferredSize(new Dimension(RIGHT_PANEL_WIDTH, MAP_LEGEND_PANEL_HEIGHT));

        // Titled etched border
        EtchedBorder legendPanelEtched = new EtchedBorder();
        Border titledBorder = BorderFactory.createTitledBorder(legendPanelEtched, Bundle.Import_geometrical_wizard_panel_geo_import_support_panel_legend_label());

        mapLegendPanel.setBorder(titledBorder);
        rightPanel.add(mapLegendPanel);
    }

    public ShapePropertiesPanel getShapePropertiesPanel() {
        return shapePropertiesPanel;
    }

    private void setShapePropertiesPanel(ShapePropertiesPanel shapePropertiesPanel) {
        this.shapePropertiesPanel = shapePropertiesPanel;

        shapePropertiesPanel.setMinimumSize(new Dimension(RIGHT_PANEL_WIDTH, PROPERTIES_PANEL_HEIGHT));
        shapePropertiesPanel.setPreferredSize(new Dimension(RIGHT_PANEL_WIDTH, PROPERTIES_PANEL_HEIGHT));
        // Titled etched border
        EtchedBorder propertiesPanelEtched = new EtchedBorder();
        Border titledBorder = BorderFactory.createTitledBorder(propertiesPanelEtched, Bundle.Import_geometrical_wizard_panel_geo_import_support_panel_shape_properties_label());

        shapePropertiesPanel.setBorder(titledBorder);
        rightPanel.add(shapePropertiesPanel);
    }

    public ShapePropertyMappingPanel getShapePropertySelectorPanel() {
        return shapePropertyMappingPanel;
    }

    private void setShapePropertyMappingPanel(ShapePropertyMappingPanel shapePropertyMappingPanel) {
        this.shapePropertyMappingPanel = shapePropertyMappingPanel;

        shapePropertyMappingPanel.setMinimumSize(new Dimension(RIGHT_PANEL_WIDTH, MAPPING_PANEL_HEIGHT));
        shapePropertyMappingPanel.setPreferredSize(new Dimension(RIGHT_PANEL_WIDTH, MAPPING_PANEL_HEIGHT));
        // Titled etched border
        EtchedBorder propertySelectorPanelEtched = new EtchedBorder();
        Border titledBorder = BorderFactory.createTitledBorder(propertySelectorPanelEtched, Bundle.Shape_property_mapping_panel());

        shapePropertyMappingPanel.setBorder(titledBorder);
        rightPanel.add(shapePropertyMappingPanel);
    }

    public MarkAsPanel getMarkAsPanel() {
        return markAsPanel;
    }

    private void setMarkAsPanel(MarkAsPanel markAsPanel) {
        this.markAsPanel = markAsPanel;

        // Titled etched border
        EtchedBorder markAsPanelEtched = new EtchedBorder();
        Border titledBorder = BorderFactory.createTitledBorder(markAsPanelEtched, Bundle.Import_geometrical_wizard_panel_geo_import_support_panel_mark_as_label());

        markAsPanel.setBorder(titledBorder);
        this.add(markAsPanel);
    }

    private void initRightPanel() {
        this.add(rightPanel);
    }

    public static final class Builder {

        private ShapesPanel leftPanel;
        private ShapePropertiesPanel shapePropertiesPanel;
        private ShapePropertyMappingPanel shapePropertyMappingPanel;
        private MapLegendPanel mapLegendPanel;
        private MarkAsPanel markAsPanel;

        public Builder setLeftPanel(ShapesPanel leftPanel) {
            this.leftPanel = leftPanel;
            return this;
        }

        public Builder setMapLegendPanel(MapLegendPanel mapLegendPanel) {
            this.mapLegendPanel = mapLegendPanel;
            return this;
        }

        public Builder setMarkAsPanel(MarkAsPanel markAsPanel) {
            this.markAsPanel = markAsPanel;
            return this;
        }

        public Builder setShapePropertiesPanel(ShapePropertiesPanel shapePropertiesPanel) {
            this.shapePropertiesPanel = shapePropertiesPanel;
            return this;
        }

        public Builder setShapePropertyMappingPanel(ShapePropertyMappingPanel shapePropertyMappingPanel) {
            this.shapePropertyMappingPanel = shapePropertyMappingPanel;
            return this;
        }

        public ShapePreviewPanel build() {
            ShapePreviewPanel panel = new ShapePreviewPanel();
            assert leftPanel != null : "leftPanel is required to build ShapePreviewPanel";
            assert mapLegendPanel != null : "mapLegendPanel is required to build ShapePreviewPanel";
            assert shapePropertyMappingPanel != null : "shapePropertyMappingPanel is required to build ShapePreviewPanel";
            assert shapePropertiesPanel != null : "shapePropertiesPanel is required to build ShapePreviewPanel";
            assert markAsPanel != null : "markAsPanel is required to build ShapePreviewPanel";

            panel.setLeftPanel(leftPanel);
            panel.setMapLegendPanel(mapLegendPanel);
            panel.setShapePropertyMappingPanel(shapePropertyMappingPanel);
            panel.setShapePropertiesPanel(shapePropertiesPanel);
            panel.initRightPanel();
            //panel.setMarkAsPanel(markAsPanel);
            return panel;
        }
    }
}
